@@ -8,7 +8,6 @@ from datetime import datetime
 import pendulum
 import psutil
 
-
 def job_phases_for_tmpdir(d, all_jobs):
     '''Return phase 2-tuples for jobs running on tmpdir d'''
     return sorted([j.progress() for j in all_jobs if j.tmpdir == d])
@@ -74,6 +73,8 @@ class Job:
     # These are dynamic, cached, and need to be udpated periodically
     phase = (None, None)  # Phase/subphase
 
+    last_updated_time_in_min = 0
+
     def get_running_jobs(logroot, cached_jobs=()):
         '''Return a list of running plot jobs.  If a cache of preexisting jobs is provided,
            reuse those previous jobs without updating their information.  Always look for
@@ -197,6 +198,7 @@ class Job:
 
     def update_from_logfile(self):
         self.set_phase_from_logfile()
+        self.check_freeze()
 
     def set_phase_from_logfile(self):
         assert self.logfile
@@ -249,6 +251,12 @@ class Job:
         else:
             self.phase = (0, 0)
 
+    def check_freeze(self):
+        assert self.logfile
+        updatedAt = os.path.getmtime(self.logfile)
+        now = datetime.now().timestamp()
+        self.last_updated_time_in_min = int((now-updatedAt)/60);
+
     def progress(self):
         '''Return a 2-tuple with the job phase and subphase (by reading the logfile)'''
         return self.phase
